@@ -51,6 +51,7 @@
 
 #ifdef HAVE_GTOP
 #define TIME_WITH_SYS_TIME 1
+#define HAVE_SYS_TIME_H 1
 #include <glibtop/procuid.h>
 #include <errno.h>
 #include <pwd.h>
@@ -286,14 +287,6 @@ reload_net_wm_icon (MetaWindow    *window,
   reload_icon (window, window->display->atom__NET_WM_ICON);
 }
 
-static void
-reload_kwm_win_icon (MetaWindow    *window,
-                     MetaPropValue *value,
-                     gboolean       initial)
-{
-  reload_icon (window, window->display->atom__KWM_WIN_ICON);
-}
-
 static void
 meta_window_set_custom_frame_extents (MetaWindow *window,
                                       GtkBorder  *extents)
@@ -395,6 +388,28 @@ reload_wm_window_role (MetaWindow    *window,
     window->role = g_strdup (value->v.str);
 }
 
+static void
+reload_net_wm_pid (MetaWindow    *window,
+                   MetaPropValue *value,
+                   gboolean       initial)
+{
+  if (value->type != META_PROP_VALUE_INVALID)
+    {
+      gulong cardinal = (int) value->v.cardinal;
+
+      if (cardinal <= 0)
+        {
+          g_warning ("Application set a bogus _NET_WM_PID %lu", cardinal);
+        }
+      else
+        {
+          window->net_wm_pid = cardinal;
+          meta_verbose ("Window has _NET_WM_PID %d\n",
+                        window->net_wm_pid);
+        }
+    }
+}
+
 static void
 reload_net_wm_user_time (MetaWindow    *window,
                          MetaPropValue *value,
@@ -1148,13 +1163,6 @@ meta_set_normal_hints (MetaWindow *window,
   w = window->size_hints.width;
   h = window->size_hints.height;
 
-  /* as far as I can tell, value->v.size_hints.flags is just to
-   * check whether we had old-style normal hints without gravity,
-   * base size as returned by XGetNormalHints(), so we don't
-   * really use it as we fixup window->size_hints to have those
-   * fields if they're missing.
-   */
-
   /*
    * When the window is first created, NULL hints will
    * be passed in which will initialize all of the fields
@@ -1189,7 +1197,6 @@ meta_set_normal_hints (MetaWindow *window,
       window->size_hints.base_width = 0;
       window->size_hints.base_height = 0;
     }
-  window->size_hints.flags |= PBaseSize;
 
   /* Get min size hints */
   if (window->size_hints.flags & PMinSize)
@@ -1206,10 +1213,9 @@ meta_set_normal_hints (MetaWindow *window,
     }
   else
     {
-      window->size_hints.min_width = 0;
-      window->size_hints.min_height = 0;
+      window->size_hints.min_width = 1;
+      window->size_hints.min_height = 1;
     }
-  window->size_hints.flags |= PMinSize;
 
   /* Get max size hints */
   if (window->size_hints.flags & PMaxSize)
@@ -1223,7 +1229,6 @@ meta_set_normal_hints (MetaWindow *window,
     {
       window->size_hints.max_width = G_MAXINT;
       window->size_hints.max_height = G_MAXINT;
-      window->size_hints.flags |= PMaxSize;
     }
 
   /* Get resize increment hints */
@@ -1239,7 +1244,6 @@ meta_set_normal_hints (MetaWindow *window,
     {
       window->size_hints.width_inc = 1;
       window->size_hints.height_inc = 1;
-      window->size_hints.flags |= PResizeInc;
     }
 
   /* Get aspect ratio hints */
@@ -1259,7 +1263,6 @@ meta_set_normal_hints (MetaWindow *window,
       window->size_hints.min_aspect.y = G_MAXINT;
       window->size_hints.max_aspect.x = G_MAXINT;
       window->size_hints.max_aspect.y = 1;
-      window->size_hints.flags |= PAspect;
     }
 
   /* Get gravity hint */
@@ -1271,11 +1274,14 @@ meta_set_normal_hints (MetaWindow *window,
     }
   else
     {
-      meta_topic (META_DEBUG_GEOMETRY,
-                  "Window %s doesn't set gravity, using NW\n",
-                  window->desc);
       window->size_hints.win_gravity = NorthWestGravity;
-      window->size_hints.flags |= PWinGravity;
+
+      if (hints != NULL)
+        {
+          meta_topic (META_DEBUG_GEOMETRY,
+                      "Window %s doesn't set gravity, using NW\n",
+                      window->desc);
+        }
     }
 
   /*** Lots of sanity checking ***/
@@ -1484,9 +1490,10 @@ reload_normal_hints (MetaWindow    *window,
 
       old_hints = window->size_hints;
 
-      meta_set_normal_hints (window, value->v.size_hints.hints);
+      meta_set_normal_hints (window, value->v.size_hints);
 
-      spew_size_hints_differences (&old_hints, &window->size_hints);
+      if (!initial)
+        spew_size_hints_differences (&old_hints, &window->size_hints);
 
       meta_window_recalc_features (window);
 
@@ -1788,6 +1795,12 @@ meta_display_init_window_prop_hooks (MetaDisplay *display)
       reload_wm_class,
       LOAD_INIT | INCLUDE_OR
     },
+    {
+      display->atom__NET_WM_PID,
+      META_PROP_VALUE_CARDINAL,
+      reload_net_wm_pid,
+      LOAD_INIT | INCLUDE_OR
+    },
     {
       XA_WM_NAME,
       META_PROP_VALUE_TEXT_PROPERTY,
@@ -1884,12 +1897,6 @@ meta_display_init_window_prop_hooks (MetaDisplay *display)
       reload_net_wm_icon,
       NONE
     },
-    {
-      display->atom__KWM_WIN_ICON,
-      META_PROP_VALUE_INVALID,
-      reload_kwm_win_icon,
-      NONE
-    },
     {
       display->atom__NET_WM_ICON_GEOMETRY,
       META_PROP_VALUE_CARDINAL_LIST,
